@@ -6,7 +6,6 @@ import grokcore.view
 import grokcore.viewlet
 import grokcore.component
 
-from martian import util
 from megrok.pagetemplate.components import PageTemplate
 from zope.pagetemplate.interfaces import IPageTemplate
 from zope.publisher.interfaces.browser import IDefaultBrowserLayer
@@ -22,7 +21,8 @@ class PageTemplateGrokker(martian.ClassGrokker):
 
     def grok(self, name, factory, module_info, **kw):
         factory.module_info = module_info
-        return martian.ClassGrokker.grok(self, name, factory, module_info, **kw)
+        return martian.ClassGrokker.grok(
+            self, name, factory, module_info, **kw)
 
     def execute(self, factory, config, name, view, layer, provides, **kw):
         pagetemplate = factory()
@@ -32,16 +32,14 @@ class PageTemplateGrokker(martian.ClassGrokker):
             config.action(
                 discriminator=None,
                 callable=self.checkTemplates,
-                args=(templates, factory.module_info, factory)
-                )
+                args=(templates, factory.module_info, factory))
 
         adapts = (view, layer)
         config.action(
             discriminator=('adapter', adapts, provides, name),
             callable=zope.component.provideAdapter,
-            args=(pagetemplate, adapts, provides, name),
-            )
-        
+            args=(pagetemplate, adapts, provides, name))
+
         return True
 
     def checkTemplates(self, templates, module_info, factory):
@@ -51,6 +49,6 @@ class PageTemplateGrokker(martian.ClassGrokker):
 
         def has_no_render(factory):
             return True
-        
+
         templates.checkTemplates(module_info, factory, 'pagetemplate',
                                  has_render, has_no_render)
